DELETE: messages.json
---------------------

It deletes SFChat messages. It’s send after successfully delivering message.
Therefore SFChat server keeps only undelivered messages.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   Request
   Response
